==> Evergreen-ILS-3.15.7.tar.gz: Evergreen-ILS-3.15.7/Open-ILS/web/js/dojo/openils/acq/nls/pt-br/acq.js <==
{
    ":CREATE_PO_ASSETS_CONFIRM": "Isso ir\u00e1 criar um registro bibliogr\u00e1fico, n\u00famero de chamada, e os registros de exemplares para este pedido de compra no SIB.\n\nContinuar?",
    ":ROLLBACK_PO_RECEIVE_CONFIRM": "Isto ir\u00e1 reverter o recebimento de todos os exemplares para este pedido de compra.\n\nContinuar?",
    ":ROLLBACK_LI_RECEIVE_CONFIRM": "Isto ir\u00e1 reverter o recebimento de todos os exemplares para este pedido de compra.\n\nContinuar?",
    ":XUL_RECORD_DETAIL_PAGE": "Detalhes de Registro",
    ":DELETE_LI_COPIES_CONFIRM": "Esta opera\u00e7\u00e3o apagar\u00e1 as ultimas ${0} c\u00f3pias na tabela.  Proceder?",
    ":NO_PO_RESULTS": "Sem resultados",
    ":PO_HEADING_ERROR": "Problema inesperado ao criar um OP virtual combinada",
    ":CONFIRM_SPLIT_PO": "Tem certeza de que quer dividir este pedido de compra em\num pedido de compra para cada item?",
    ":DFA_NOT_ALL": "Could not record all of your applications of distribution formulas.",
    ":APPLY": "Aplicar",
    ":RESET_FORMULAE": "Reiniciar f\u00f3rmulas",
    ":OUT_OF_COPIES": "Voc\u00ea aplicou as f\u00f3rmulas de distribui\u00e7\u00e3o para cada c\u00f3pia.",
    ":ONE_LI_ATTR_SEARCH_AT_A_TIME": "Voc\u00ea n\u00e3o pode digitar num atributo para pesquisa  e ao mesmo tempo procurar por um aquivo de termos de pesquisa carregado.",
    ":LI_ATTR_SEARCH_CHOOSE_FILE": "Selecionar arquivo com termos de pesquisa",
    ":LI_ATTR_SEARCH_TOO_LARGE": "Este arquivo \u00e9 muito grande para esta opera\u00e7\u00e3o.",
    ":SELECT_AN_LI_ATTRIBUTE": "Voc\u00ea deve selecionar um atributo do item",
    ":NO_RESULTS": "Sem resultados.",
    ":EXPORT_SAVE_DIALOG_TITLE": "Salvar valores do campo em um arquivo",
    ":EXPORT_SHORT_LIST": "Nem todos os itens selecionados tem o atributo '${0}'.\nEscolha OK para salvar aqueles valores que foram encontrados.",
    ":EXPORT_EMPTY_LIST": "Nenhum valor para o atributo '${0}' encontrado.",
    ":UNRECEIVE_LI": "Voc\u00ea tem certeza que quer marcar este item como n\u00e3o recebido?",
    ":UNRECEIVE_LID": "Voc\u00ea tem certeza que deseja marcar este exemplar como n\u00e3o-recebido?",
    ":CONFIRM_LI_ALERT": "Um alerta foi colocado em lineitem titulado,\n\"${0}\":\n\n${1}\n${2}\n${3}\nClique OK se voc\u00ea deseja reconhecer esse alerta.",
    ":ALERT_UNSELECTED": "Voc\u00ea deve escolher um c\u00f3digo de alerta",
    ":DFA_TIP": "<strong>Aplicado por</strong>: ${0}<br /><strong>Quando</strong>: ${1}",
    ":ITS_YOU": "Voc\u00ea",
    ":JUST_NOW": "Agora mesmo",
    ":EXPLAIN_DFA_MGMT": "Remover o uso deste registro desta f\u00f3rmula de distribui\u00e7\u00e3o?",
    ":VENDOR_PUBLIC": "Fornecedor p\u00fablico",
    ":PO_CANCEL_CONFIRM": "Voc\u00ea tem certeza que quer Cancelar este pedido de compra?",
    ":LI_CANCEL_CONFIRM": "Voc\u00ea tem certeza que deseja cancelar este item?",
    ":LID_CANCEL_CONFIRM": "Voc\u00ea tem certeza que deseja cancelar esta c\u00f3pia?",
    ":UR_CANCEL_CONFIRM": "Voc\u00ea tem certeza que deseja cancelar esta solicita\u00e7\u00e3o do usu\u00e1rio?",
    ":UR_FILTER_USER": "Entre com o c\u00f3digo de barras para o usu\u00e1rio (ou deixe em branco para remover o filtro):",
    ":UR_FILTER_LINEITEM": "Entre com uma identifica\u00e7\u00e3o para o Item desta linha (ou deixe em branco para remover o filtro):",
    ":CANCEL_REASON": "Motivo do cancelamento",
    ":CANCEL": "Cancelar",
    ":YES": "Sim",
    ":NO": "N\u00e3o",
    ":VENDOR_SAYS_PREPAY_NOT_NEEDED": "De acordo com os registros  o fornecedor selecionado n\u00e3o necessariamente requer pr\u00e9-pagamento. Requerer pr\u00e9-pagamento neste OP?",
    ":VENDOR_SAYS_PREPAY_NEEDED": "O fornecedor selecionado requer pagamento pr\u00e9vio, de acordo com os registros.\nProceder mesmo sem pagamento pr\u00e9vio requerido para esta OP?",
    ":PREPAYMENT_REQUIRED_REMINDER": "Esta OP requer pagamento pr\u00e9vio. Voc\u00ea est\u00e1 certo que esta pronto pra ativa-la?",
    ":LI_FORMAT_ERROR": "Erro inesperado ao obter informa\u00e7\u00f5es formatadas do item.",
    ":FUND_NOT_YET_LOADED": "O Fundo ainda esta vazio. Tente mais tarde.",
    ":CONFIRM_DELETE_MAPPING": "Voc\u00ea tem certeza que quer remover o selo deste fundo?",
    ":COULD_NOT_CREATE_MAPPING": "Erro ao marcar fundo",
    ":COULD_NOT_DELETE_MAPPING": "Erro ao remover selo do fundo.",
    ":FUND_LIST_ROLLOVER_SUMMARY": "Propaga\u00e7\u00e3o do Fundo &amp; Resumo da Rolagem para o Ano Fiscal $ {0}",
    ":FUND_LIST_ROLLOVER_SUMMARY_FUNDS": "${1} funds propagated for fiscal year ${0} for the selected locations",
    ":FUND_LIST_ROLLOVER_SUMMARY_ROLLOVER_AMOUNT": "<b>$${1}</b>  dinheiro n\u00e3o gasto rolou para o ano fiscal ${0} para os locais selecionados",
    ":FUND_XFER_SAME_SOURCE_AND_DEST": "N\u00e3o \u00e9 poss\u00edvel transferir. Os fundos destino e origem s\u00e3o os mesmos.",
    ":FUND_XFER_CONFIRM": "Tem certeza de que est\u00e1 pronto para finalizar esta transfer\u00eancia?",
    ":PO_ACTIVATED_ON": "Ativada $(0)",
    ":PO_CHECKING": "[Um momento ...]",
    ":PO_COULD_ACTIVATE": "Sim.",
    ":PO_WARNING_NO_BLOCK_ACTIVATION": "Sim; o fundo ${0} (${1}) ficaria comprometido al\u00e9m do n\u00edvel de alerta.",
    ":PO_STOP_BLOCKS_ACTIVATION": "N\u00e3o, o fundo ${0} (${1}) ficariam comprometidos para al\u00e9m do seu n\u00edvel de alerta.",
    ":PO_ALREADY_ACTIVATED": "Activated",
    ":PO_FUND_WARNING_CONFIRM": "Voc\u00ea tem certeza? Voc\u00ea viu o alerta sobre comprometimento excessivo de um fundo?",
    ":CONFIRM_FUNDS_AT_STOP": "Um ou mais desses fundos selecionados tem um saldo menor que o limite m\u00ednimo.\nVoc\u00ea pode n\u00e3o ser capaz de ativar os pedidos de compra incorporando estes exemplares.\nContinuar?",
    ":CONFIRM_FUNDS_AT_WARNING": "Um ou mais dos fundos selecionados tem um saldo menor que o n\u00edvel de alerta\nContinuar?",
    ":INVOICE_ITEM_DETAILS": "${0} <br/> ${1} <br/> ${2}. <br/> Pre\u00e7o estimado: $${3}. <br/>  ID do item: ${4} <br/> CEP: ${5} <br/> Data do pedido: ${6}",
    ":INVOICE_CONFIRM_ITEM_DELETE": "Remover este custo $${0} '${1}' da fatura?",
    ":INVOICE_CONFIRM_ENTRY_DETACH": "Remover $${0} custo para item '${1}, ${2} [${3}] da fatura?",
    ":LINEITEM_SUMMARY": "<div class='acq-lineitem-summary'><a target='_top' href='${19}'>${0}</a>, by ${1} (${2})</div>\n<div class='acq-lineitem-summary-extra'>\n${3} Ordered, ${4} Received, ${7} Invoiced, ${8} Claimed, ${9} Cancelled, ${23} Delayed</div>\n<div class='acq-lineitem-summary-extra'>Estimated $${6}, Encumbered $${16}, Paid $${17}</div>\n<div class='acq-lineitem-summary-extra'>\n# ${10} <a style='padding-right: 10px;' class='hidden${20}'  target='_top' href='/eg2/en-US/staff/acq/po/${12}#${10}'>&#x2318; ${13} ${18}</a>\n<a style='padding-right: 10px;' class='hidden${21}' target='_top' href='/eg2/en-US/staff/acq/picklist/${14}#${10}'>&#x2756; ${15}</a></div>",
    ":INVOICE_CONFIRM_PRORATE": "Ratear custos?\n\nPosteriormente quaisquer altera\u00e7\u00f5es a fatura que afetar o montante rateado dever\u00e1 ser resolvido manualmente.",
    ":INVOICE_EXTRA_COPIES": "Voc\u00ea est\u00e1 tentando faturar <b> $ {0} </ b> mais exemplares do que originalmente solicitados. <br/> Para adicionar esses itens para o pedido original, selecione abaixo. um fundo e escolha 'Adicionar novos itens'  <br/> Depois de salvar a fatura, voc\u00ea pode terminar a edi\u00e7\u00e3o e importar as novas c\u00f3pias da p\u00e1gina de informa\u00e7\u00f5es de Item.",
    ":INVOICE_ITEM_PO_DETAILS": "<b>${0}</b><br/><a target='_top' href='/eg2/en-US/staff/acq/po/${2}'>PO #${3} ${4}</a><br/>Total Estimated Cost: $${5}",
    ":INVOICE_ITEM_PO_LABEL": "<a target='_top' href='/eg2/en-US/staff/acq/po/${1}'>PO #${2} ${3}</a><br/>Total Estimated Cost: $${4}",
    ":UNNAMED": "Sem nome",
    ":NO_FIND_INVOICE": "N\u00e3o foi poss\u00edvel encontrar a fatura.\nObserve que s\u00e3o diferenciados mai\u00fasculas e min\u00fasculas para nomes de #Faturas",
    ":LI_BATCH_UPDATE": "Line item batch update",
    ":NO_LI_TO_UPDATE": "You have not selected any line items to update.",
    ":NO_LI_TO_CLAIM": "You have not selected any line items to claim.",
    ":NO_LID_TO_CLAIM": "You have not selected any line item details to claim.",
    ":CHANGE_CLAIM_POLICY": "Mudar pol\u00edtica de solicita\u00e7\u00e3o",
    ":CANCELED": "Cancelada",
    ":RECVD": "Recebido",
    ":NOT_RECVD": "N\u00e3o recebido",
    ":PRINT": "Imprimir",
    ":INVOICES": "Faturas",
    ":NUM_CLAIMS_EXISTING": "Solicita\u00e7\u00f5es (${0} existentes)",
    ":LOAD_TERMS_FIRST": "Voc\u00ea n\u00e3o pode obter registos at\u00e9 que voc\u00ea tenha carregado um arquivo CSV\ncom IDs bibliogr\u00e1ficos na primeira coluna.",
    ":SELECT_SEARCH_FIELD": "Selecionar campo de pesquisa",
    ":LIBRARY_INITIATED": "Biblioteca inicializada",
    ":DEL_LI_FROM_PO": "Esse item j\u00e1 foi encomendado! Exclu\u00ed-lo agora n\u00e3o vai revogar ou modificar qualquer pedido que tenha sido feito para um fornecedor. Excluindo o item pode colocar o a situa\u00e7\u00e3o no sistema para seu pedido de compra num estado que \u00e9 inconsistente com a realidade. Voc\u00ea tem certeza que esta \u00e9 a sua inten\u00e7\u00e3o?",
    ":ADD_LI_TO_PO_BAD_PO_STATE": "A OP selecionada j\u00e1 foi ativada",
    ":ADD_LI_TO_PO_BAD_LI_STATE": "O item selecionado n\u00e3o est\u00e1 numa situa\u00e7\u00e3o que permite ser adicionado a uma ordem de compra",
    ":INVOICE_NUMBER": "Fatura #${0}",
    ":COPIES_TO_RECEIVE": "N\u00famero de c\u00f3pias para receber: ",
    ":CREATE_PO_INVALID": "O pedido de compra deve ter uma ag\u00eancia de encomenda e um fornecedor.",
    ":INVOICE_COPY_COUNT_INFO": "Exemplares recebidos desta fatura: ${0} de ${1}.",
    ":INVOICE_IDENT_COLLIDE": "J\u00e1 existe uma nota fiscal no sistema com a combina\u00e7\u00e3o fornecida  de  'ID  Fatura Fornecedor' e 'Fornecedor', o que n\u00e3o \u00e9 permitido.",
    ":NEW_INVOICE": "New Invoice",
    ":ACQ_SEARCH_CLASS_ABBR_jub": "LI",
    ":ACQ_SEARCH_CLASS_ABBR_acqpl": "SL",
    ":ACQ_SEARCH_CLASS_ABBR_acqpo": "PO",
    ":ACQ_SEARCH_CLASS_ABBR_acqinv": "I",
    ":ACQ_SEARCH_CLASS_ABBR_acqlid": "LID",
    ":ACQ_SEARCH_CLASS_ABBR_acqlia": "LIA",
    ":NO_LI_GENERAL": "You have not selected any (suitable) line items.",
    ":DUPE_PO_NAME_MSG": "This name is already in use by another PO",
    ":DUPE_PO_NAME_LINK": "View PO",
    ":PO_NAME_OPTIONAL": "${0} (optional)",
    ":FINALIZE_PO": "Finalize this blanket PO?\nThis will disencumber all blanket charges and mark the PO as received",
    ":LI_EXISTING_COPIES": "There are ${0} existing copies for this bibliographic record at this location",
    ":LI_CREATING_ASSETS": "Creating bib, call number, and copy records...",
    ":PO_ACTIVATING": "Activating purchase order...",
    ":ACTIVATE_LI_PROCESSED": "Lineitems Processed: ${0}",
    ":ACTIVATE_VQBR_PROCESSED": "Vandelay Records Processed: ${0}",
    ":ACTIVATE_BIBS_PROCESSED": "Bib Records Merged/Imported: ${0}",
    ":ACTIVATE_LID_PROCESSED": "ACQ Copies Processed: ${0}",
    ":ACTIVATE_DEBITS_ACCRUED_PROCESSED": "Debits Encumbered: ${0}",
    ":ACTIVATE_COPIES_PROCESSED": "Real Copies Processed: ${0}"
}

==> Evergreen-ILS-3.16.0.tar.gz: Evergreen-ILS-3.16.0/Open-ILS/web/js/dojo/openils/acq/nls/pt-br/acq.js <==
{
    ":CREATE_PO_ASSETS_CONFIRM": "Isso ir\u00e1 criar um registro bibliogr\u00e1fico, n\u00famero de chamada, e os registros de exemplares para este pedido de compra no SIB.\n\nContinuar?",
    ":ROLLBACK_PO_RECEIVE_CONFIRM": "Isto ir\u00e1 reverter o recebimento de todos os exemplares para este pedido de compra.\n\nContinuar?",
    ":ROLLBACK_LI_RECEIVE_CONFIRM": "Isto ir\u00e1 reverter o recebimento de todos os exemplares para este pedido de compra.\n\nContinuar?",
    ":XUL_RECORD_DETAIL_PAGE": "Detalhes de Registro",
    ":DELETE_LI_COPIES_CONFIRM": "Esta opera\u00e7\u00e3o apagar\u00e1 as ultimas ${0} c\u00f3pias na tabela.  Proceder?",
    ":NO_PO_RESULTS": "Sem resultados",
    ":PO_HEADING_ERROR": "Problema inesperado ao criar um OP virtual combinada",
    ":CONFIRM_SPLIT_PO": "Tem certeza de que quer dividir este pedido de compra em\num pedido de compra para cada item?",
    ":DFA_NOT_ALL": "N\u00e3o foi poss\u00edvel gravar todas aplica\u00e7\u00f5es suas de f\u00f3rmulas de distribui\u00e7\u00e3o.",
    ":APPLY": "Aplicar",
    ":RESET_FORMULAE": "Reiniciar f\u00f3rmulas",
    ":OUT_OF_COPIES": "Voc\u00ea aplicou as f\u00f3rmulas de distribui\u00e7\u00e3o para cada c\u00f3pia.",
    ":ONE_LI_ATTR_SEARCH_AT_A_TIME": "Voc\u00ea n\u00e3o pode digitar num atributo para pesquisa  e ao mesmo tempo procurar por um aquivo de termos de pesquisa carregado.",
    ":LI_ATTR_SEARCH_CHOOSE_FILE": "Selecionar arquivo com termos de pesquisa",
    ":LI_ATTR_SEARCH_TOO_LARGE": "Este arquivo \u00e9 muito grande para esta opera\u00e7\u00e3o.",
    ":SELECT_AN_LI_ATTRIBUTE": "Voc\u00ea deve selecionar um atributo do item",
    ":NO_RESULTS": "Sem resultados.",
    ":EXPORT_SAVE_DIALOG_TITLE": "Salvar valores do campo em um arquivo",
    ":EXPORT_SHORT_LIST": "Nem todos os itens selecionados tem o atributo '${0}'.\nEscolha OK para salvar aqueles valores que foram encontrados.",
    ":EXPORT_EMPTY_LIST": "Nenhum valor para o atributo '${0}' encontrado.",
    ":UNRECEIVE_LI": "Voc\u00ea tem certeza que quer marcar este item como n\u00e3o recebido?",
    ":UNRECEIVE_LID": "Voc\u00ea tem certeza que deseja marcar este exemplar como n\u00e3o-recebido?",
    ":CONFIRM_LI_ALERT": "Um alerta foi colocado em lineitem titulado,\n\"${0}\":\n\n${1}\n${2}\n${3}\nClique OK se voc\u00ea deseja reconhecer esse alerta.",
    ":ALERT_UNSELECTED": "Voc\u00ea deve escolher um c\u00f3digo de alerta",
    ":DFA_TIP": "<strong>Aplicado por</strong>: ${0}<br /><strong>Quando</strong>: ${1}",
    ":ITS_YOU": "Voc\u00ea",
    ":JUST_NOW": "Agora mesmo",
    ":EXPLAIN_DFA_MGMT": "Remover o uso deste registro desta f\u00f3rmula de distribui\u00e7\u00e3o?",
    ":VENDOR_PUBLIC": "Fornecedor p\u00fablico",
    ":PO_CANCEL_CONFIRM": "Voc\u00ea tem certeza que quer Cancelar este pedido de compra?",
    ":LI_CANCEL_CONFIRM": "Voc\u00ea tem certeza que deseja cancelar este item?",
    ":LID_CANCEL_CONFIRM": "Voc\u00ea tem certeza que deseja cancelar esta c\u00f3pia?",
    ":UR_CANCEL_CONFIRM": "Voc\u00ea tem certeza que deseja cancelar esta solicita\u00e7\u00e3o do usu\u00e1rio?",
    ":UR_FILTER_USER": "Entre com o c\u00f3digo de barras para o usu\u00e1rio (ou deixe em branco para remover o filtro):",
    ":UR_FILTER_LINEITEM": "Entre com uma identifica\u00e7\u00e3o para o Item desta linha (ou deixe em branco para remover o filtro):",
    ":CANCEL_REASON": "Motivo do cancelamento",
    ":CANCEL": "Cancelar",
    ":YES": "Sim",
    ":NO": "N\u00e3o",
    ":VENDOR_SAYS_PREPAY_NOT_NEEDED": "De acordo com os registros  o fornecedor selecionado n\u00e3o necessariamente requer pr\u00e9-pagamento. Requerer pr\u00e9-pagamento neste OP?",
    ":VENDOR_SAYS_PREPAY_NEEDED": "O fornecedor selecionado requer pagamento pr\u00e9vio, de acordo com os registros.\nProceder mesmo sem pagamento pr\u00e9vio requerido para esta OP?",
    ":PREPAYMENT_REQUIRED_REMINDER": "Esta OP requer pagamento pr\u00e9vio. Voc\u00ea est\u00e1 certo que esta pronto pra ativa-la?",
    ":LI_FORMAT_ERROR": "Erro inesperado ao obter informa\u00e7\u00f5es formatadas do item.",
    ":FUND_NOT_YET_LOADED": "O Fundo ainda esta vazio. Tente mais tarde.",
    ":CONFIRM_DELETE_MAPPING": "Voc\u00ea tem certeza que quer remover o selo deste fundo?",
    ":COULD_NOT_CREATE_MAPPING": "Erro ao marcar fundo",
    ":COULD_NOT_DELETE_MAPPING": "Erro ao remover selo do fundo.",
    ":FUND_LIST_ROLLOVER_SUMMARY": "Propaga\u00e7\u00e3o do Fundo &amp; Resumo da Rolagem para o Ano Fiscal $ {0}",
    ":FUND_LIST_ROLLOVER_SUMMARY_FUNDS": "<b>${1}</b> fundos propagados para o ano fiscal ${0} para as localiza\u00e7\u00f5es selecionadas",
    ":FUND_LIST_ROLLOVER_SUMMARY_ROLLOVER_AMOUNT": "<b>$${1}</b>  dinheiro n\u00e3o gasto rolou para o ano fiscal ${0} para os locais selecionados",
    ":FUND_XFER_SAME_SOURCE_AND_DEST": "N\u00e3o \u00e9 poss\u00edvel transferir. Os fundos destino e origem s\u00e3o os mesmos.",
    ":FUND_XFER_CONFIRM": "Tem certeza de que est\u00e1 pronto para finalizar esta transfer\u00eancia?",
    ":PO_ACTIVATED_ON": "Ativada $(0)",
    ":PO_CHECKING": "[Um momento ...]",
    ":PO_COULD_ACTIVATE": "Sim.",
    ":PO_WARNING_NO_BLOCK_ACTIVATION": "Sim; o fundo ${0} (${1}) ficaria comprometido al\u00e9m do n\u00edvel de alerta.",
    ":PO_STOP_BLOCKS_ACTIVATION": "N\u00e3o, o fundo ${0} (${1}) ficariam comprometidos para al\u00e9m do seu n\u00edvel de alerta.",
    ":PO_ALREADY_ACTIVATED": "Activated",
    ":PO_FUND_WARNING_CONFIRM": "Voc\u00ea tem certeza? Voc\u00ea viu o alerta sobre comprometimento excessivo de um fundo?",
    ":CONFIRM_FUNDS_AT_STOP": "Um ou mais desses fundos selecionados tem um saldo menor que o limite m\u00ednimo.\nVoc\u00ea pode n\u00e3o ser capaz de ativar os pedidos de compra incorporando estes exemplares.\nContinuar?",
    ":CONFIRM_FUNDS_AT_WARNING": "Um ou mais dos fundos selecionados tem um saldo menor que o n\u00edvel de alerta\nContinuar?",
    ":INVOICE_ITEM_DETAILS": "${0} <br/> ${1} <br/> ${2}. <br/> Pre\u00e7o estimado: $${3}. <br/>  ID do item: ${4} <br/> CEP: ${5} <br/> Data do pedido: ${6}",
    ":INVOICE_CONFIRM_ITEM_DELETE": "Remover este custo $${0} '${1}' da fatura?",
    ":INVOICE_CONFIRM_ENTRY_DETACH": "Remover $${0} custo para item '${1}, ${2} [${3}] da fatura?",
    ":LINEITEM_SUMMARY": "<div class='acq-lineitem-summary'><a href='${19}'>${0}</a>, por ${1} (${2})</div>\n<div class='acq-lineitem-summary-extra'>\n${3} Pedidos, ${4} Recebidos, ${7} Faturados, ${8} Solicitados, ${9} Cancelados</div>\n<div class='acq-lineitem-summary-extra'>Estimados $${6}, Comprometidos $${16}, Pagos $${17}</div>\n<div class='acq-lineitem-summary-extra'>\n# ${10} <a style='padding-right: 10px;' class='hidden${20}'  href='${11}/acq/po/view/${12}'>&#x2318; ${13} ${18}</a>\n<a style='padding-right: 10px;' class='hidden${21}' href='${11}/acq/picklist/view/${14}'>&#x2756; ${15}</a></div>",
    ":INVOICE_CONFIRM_PRORATE": "Ratear custos?\n\nPosteriormente quaisquer altera\u00e7\u00f5es a fatura que afetar o montante rateado dever\u00e1 ser resolvido manualmente.",
    ":INVOICE_EXTRA_COPIES": "Voc\u00ea est\u00e1 tentando faturar <b> $ {0} </ b> mais exemplares do que originalmente solicitados. <br/> Para adicionar esses itens para o pedido original, selecione abaixo. um fundo e escolha 'Adicionar novos itens'  <br/> Depois de salvar a fatura, voc\u00ea pode terminar a edi\u00e7\u00e3o e importar as novas c\u00f3pias da p\u00e1gina de informa\u00e7\u00f5es de Item.",
    ":INVOICE_ITEM_PO_DETAILS": "<b>${0}</b><br/><a target='_top' href='/eg2/en-US/staff/acq/po/${2}'>PO #${3} ${4}</a><br/>Total Estimated Cost: $${5}",
    ":INVOICE_ITEM_PO_LABEL": "<a target='_top' href='/eg2/en-US/staff/acq/po/${1}'>PO #${2} ${3}</a><br/>Total Estimated Cost: $${4}",
    ":UNNAMED": "Sem nome",
    ":NO_FIND_INVOICE": "N\u00e3o foi poss\u00edvel encontrar a fatura.\nObserve que s\u00e3o diferenciados mai\u00fasculas e min\u00fasculas para nomes de #Faturas",
    ":LI_BATCH_UPDATE": "Line item batch update",
    ":NO_LI_TO_UPDATE": "Voc\u00ea n\u00e3o selecionou nenhum item para solicitar",
    ":NO_LI_TO_CLAIM": "Voc\u00ea n\u00e3o selecionou nenhum item para solicitar",
    ":NO_LID_TO_CLAIM": "Voc\u00ea n\u00e3o selecionou nenhuma informa\u00e7\u00f5es sobre itens para solicitar.",
    ":CHANGE_CLAIM_POLICY": "Mudar pol\u00edtica de solicita\u00e7\u00e3o",
    ":CANCELED": "Cancelada",
    ":RECVD": "Recebido",
    ":NOT_RECVD": "N\u00e3o recebido",
    ":PRINT": "Imprimir",
    ":INVOICES": "Faturas",
    ":NUM_CLAIMS_EXISTING": "Solicita\u00e7\u00f5es (${0} existentes)",
    ":LOAD_TERMS_FIRST": "Voc\u00ea n\u00e3o pode obter registos at\u00e9 que voc\u00ea tenha carregado um arquivo CSV\ncom IDs bibliogr\u00e1ficos na primeira coluna.",
    ":SELECT_SEARCH_FIELD": "Selecionar campo de pesquisa",
    ":LIBRARY_INITIATED": "Biblioteca inicializada",
    ":DEL_LI_FROM_PO": "Esse item j\u00e1 foi encomendado! Exclu\u00ed-lo agora n\u00e3o vai revogar ou modificar qualquer pedido que tenha sido feito para um fornecedor. Excluindo o item pode colocar o a situa\u00e7\u00e3o no sistema para seu pedido de compra num estado que \u00e9 inconsistente com a realidade. Voc\u00ea tem certeza que esta \u00e9 a sua inten\u00e7\u00e3o?",
    ":ADD_LI_TO_PO_BAD_PO_STATE": "A OP selecionada j\u00e1 foi ativada",
    ":ADD_LI_TO_PO_BAD_LI_STATE": "O item selecionado n\u00e3o est\u00e1 numa situa\u00e7\u00e3o que permite ser adicionado a uma ordem de compra",
    ":INVOICE_NUMBER": "Fatura #${0}",
    ":COPIES_TO_RECEIVE": "N\u00famero de c\u00f3pias para receber: ",
    ":CREATE_PO_INVALID": "O pedido de compra deve ter uma ag\u00eancia de encomenda e um fornecedor.",
    ":INVOICE_COPY_COUNT_INFO": "Exemplares recebidos desta fatura: ${0} de ${1}.",
    ":INVOICE_IDENT_COLLIDE": "J\u00e1 existe uma nota fiscal no sistema com a combina\u00e7\u00e3o fornecida  de  'ID  Fatura Fornecedor' e 'Fornecedor', o que n\u00e3o \u00e9 permitido.",
    ":NEW_INVOICE": "New Invoice",
    ":ACQ_SEARCH_CLASS_ABBR_jub": "LI",
    ":ACQ_SEARCH_CLASS_ABBR_acqpl": "SL",
    ":ACQ_SEARCH_CLASS_ABBR_acqpo": "PO",
    ":ACQ_SEARCH_CLASS_ABBR_acqinv": "I",
    ":ACQ_SEARCH_CLASS_ABBR_acqlid": "LID",
    ":ACQ_SEARCH_CLASS_ABBR_acqlia": "LIA",
    ":NO_LI_GENERAL": "You have not selected any (suitable) line items.",
    ":DUPE_PO_NAME_MSG": "This name is already in use by another PO",
    ":DUPE_PO_NAME_LINK": "View PO",
    ":PO_NAME_OPTIONAL": "${0} (optional)",
    ":FINALIZE_PO": "Finalize this blanket PO?\nThis will disencumber all blanket charges and mark the PO as received",
    ":LI_EXISTING_COPIES": "There are ${0} existing copies for this bibliographic record at this location",
    ":LI_CREATING_ASSETS": "Creating bib, call number, and copy records...",
    ":PO_ACTIVATING": "Activating purchase order...",
    ":ACTIVATE_LI_PROCESSED": "Lineitems Processed: ${0}",
    ":ACTIVATE_VQBR_PROCESSED": "Vandelay Records Processed: ${0}",
    ":ACTIVATE_BIBS_PROCESSED": "Bib Records Merged/Imported: ${0}",
    ":ACTIVATE_LID_PROCESSED": "ACQ Copies Processed: ${0}",
    ":ACTIVATE_DEBITS_ACCRUED_PROCESSED": "Debits Encumbered: ${0}",
    ":ACTIVATE_COPIES_PROCESSED": "Real Copies Processed: ${0}"
}
